@@ -1,6 +1,7 @@
 """Core Curate App Settings
 """
 import os
+
 from django.conf import settings
 
 if not settings.configured:
@@ -15,3 +16,8 @@ BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 LOCALE_PATHS = (
     os.path.join(BASE_DIR, 'core_curate_registry_app/locale'),
 )
+
+
+XPATH_TITLE = "/rsm:Resource[1]/rsm:identity[1]/rsm:title"
+""" str : Xpath of the resource name/title 
+"""
\ No newline at end of file
