@@ -24,5 +24,5 @@ def start_curate(request):
         response = curate_ajax.start_curate(request)
         if response.status_code == 200:
             role = request.GET.get('role', None)
-            response.content = "{0}?role={1}".format(response.content, role)
+            response.content = "{0}?role={1}".format(response.content.decode('utf-8'), role)
         return response
